<?xml version="1.0" encoding="utf-8"?>

<!-- Original traditional Chinese translation done by ZX-WT (https://github.com/ZX-WT) -->

<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>DialogSettings</name>
    <message>
        <location filename="../ui/dialogsettings.ui" line="14"/>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="221"/>
        <source>Internet updates</source>
        <translation>網絡更新</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="230"/>
        <source>Update now</source>
        <translation>立刻更新</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="30"/>
        <source>Layout</source>
        <translation>佈局</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="64"/>
        <source>Preview on the &amp;left</source>
        <translation>在左邊預覽 (&amp;L)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="94"/>
        <source>Pre&amp;view on right side</source>
        <translation>在右邊預覽 (&amp;V)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="113"/>
        <source>Theme</source>
        <translation>主題</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="119"/>
        <source>&amp;Default</source>
        <translation>預設 (&amp;D)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="126"/>
        <source>Dar&amp;k</source>
        <translation>暗色 (&amp;K)</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="139"/>
        <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
        <translation>&lt;i&gt;(需要重開)&lt;/I&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="149"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="179"/>
        <source>Always enable preview zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="186"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="215"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="253"/>
        <source>Output messages</source>
        <translation>輸出信息</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="196"/>
        <source>Dialogs</source>
        <translation>對話</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="202"/>
        <source>Use native color dialog</source>
        <translation>改用原生色彩對話框</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="163"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="169"/>
        <source>Timeout (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="36"/>
        <source>Show institution logos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="262"/>
        <source>Notify when scheduled update fails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="304"/>
        <source>&amp;Ok</source>
        <translation>確定 (&amp;O)</translation>
    </message>
</context>
<context>
    <name>FiltersView</name>
    <message>
        <location filename="../ui/filtersview.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
</context>
<context>
    <name>GmicQt::ColorParameter</name>
    <message>
        <location filename="../src/FilterParameters/ColorParameter.cpp" line="200"/>
        <source>Select color</source>
        <translation>選取顏色</translation>
    </message>
</context>
<context>
    <name>GmicQt::DialogSettings</name>
    <message>
        <location filename="../src/DialogSettings.cpp" line="82"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="88"/>
        <source>Never</source>
        <translation>永不</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="89"/>
        <source>Daily</source>
        <translation>​每天</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="90"/>
        <source>Weekly</source>
        <translation>每週</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="91"/>
        <source>Every 2 weeks</source>
        <translation>每兩週</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="92"/>
        <source>Monthly</source>
        <translation>每月</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="94"/>
        <source>At launch (debug)</source>
        <translation>啟動時 (debug)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="102"/>
        <source>Output messages</source>
        <translation>輸出信息</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="103"/>
        <source>Quiet (default)</source>
        <translation>簡單 (預設)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="104"/>
        <source>Verbose (console)</source>
        <translation>繁複 (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="105"/>
        <source>Verbose (log file)</source>
        <translation>繁複 (log 檔案)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="106"/>
        <source>Very verbose (console)</source>
        <translation>超繁複 (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="107"/>
        <source>Very verbose (log file)</source>
        <translation>超繁複 (log 檔案)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="108"/>
        <source>Debug (console)</source>
        <translation>Debug (控制台)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="109"/>
        <source>Debug (log file)</source>
        <translation>Debug (log 檔案)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="125"/>
        <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
        <translation>勾選以使用原生色彩對話框，不選以使用Qt</translation>
    </message>
</context>
<context>
    <name>GmicQt::FileParameter</name>
    <message>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="157"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="160"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="163"/>
        <source>Select a file</source>
        <translation>選取檔案</translation>
    </message>
</context>
<context>
    <name>GmicQt::FilterParametersWidget</name>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="43"/>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="251"/>
        <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
        <translation>&lt;i&gt;選擇濾鏡&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="218"/>
        <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
        <translation>&lt;i&gt;沒有參數&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="223"/>
        <source>Error parsing filter parameters

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::FiltersPresenter</name>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="477"/>
        <source>Unknown filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="574"/>
        <source>Cannot find this fave&apos;s original filter
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::FiltersView</name>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="68"/>
        <source>Rename fave</source>
        <translation>重新命名最愛列</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="70"/>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="347"/>
        <source>Remove fave</source>
        <translation>從最愛移除</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="72"/>
        <source>Clone fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="76"/>
        <source>Add fave</source>
        <translation>加到最愛列</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="348"/>
        <source>Do you really want to remove the following fave?

%1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::FolderParameter</name>
    <message>
        <location filename="../src/FilterParameters/FolderParameter.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>選取資料夾</translation>
    </message>
</context>
<context>
    <name>GmicQt::GmicProcessor</name>
    <message>
        <location filename="../src/GmicProcessor.cpp" line="299"/>
        <source>Image #%1 returned by filter has %2 channels (should be at most 4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GmicProcessor.cpp" line="333"/>
        <source>Image #%1 returned by filter has %2 channels
(should be at most 4)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::HeadlessProcessor</name>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="81"/>
        <source>At least a filter path or a filter command must be provided.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="83"/>
        <source>Custom command (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="91"/>
        <source>Cannot find filter matching path %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="98"/>
        <source>Error parsing filter parameters definition for filter:

%1

Cannot retrieve default parameters.

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="112"/>
        <source>Error parsing supplied command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="115"/>
        <source>Supplied command (%1) does not match path (%2), (should be %3).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="229"/>
        <source>Filter execution failed, but with no error message.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::InOutPanel</name>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="63"/>
        <source>Input layers</source>
        <translation>輸入圖層</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
        <source>Active (default)</source>
        <translation>啟用中 (預設)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="71"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="72"/>
        <source>Active and below</source>
        <translation>啟用中和以下的</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="73"/>
        <source>Active and above</source>
        <translation>啟用中和以上的</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="74"/>
        <source>All visible</source>
        <translation>全部可見</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="75"/>
        <source>All invisible</source>
        <translation>全部隱藏</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="86"/>
        <source>Output mode</source>
        <translation>輸出模式</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="92"/>
        <source>In place (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="93"/>
        <source>New layer(s)</source>
        <translation>新增圖層</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="94"/>
        <source>New active layer(s)</source>
        <translation>新增圖層</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="95"/>
        <source>New image</source>
        <translation>新增圖片</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="206"/>
        <source>Input / Output</source>
        <translation>輸入／輸出</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="208"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="210"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::LanguageSelectionWidget</name>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="51"/>
        <source>System default (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="107"/>
        <source>Add fave</source>
        <translation>加到最愛列</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="109"/>
        <source>Reset parameters to default values</source>
        <translation>重設參數成預設值</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="115"/>
        <source>Copy G&apos;MIC command to clipboard</source>
        <translation>将G&apos;MIC命令复制到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="122"/>
        <source>Rename fave</source>
        <translation>重新命名最愛列</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="124"/>
        <source>Remove fave</source>
        <translation>從最愛移除</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="128"/>
        <source>Expand/Collapse all</source>
        <translation>全部展開／折疊</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="130"/>
        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="137"/>
        <source>Selection mode</source>
        <translation>選取模式</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="175"/>
        <source>Update filters</source>
        <translation>更新濾鏡</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="343"/>
        <source>Update completed</source>
        <translation>更新完成</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="343"/>
        <location filename="../src/MainWindow.cpp" line="345"/>
        <location filename="../src/MainWindow.cpp" line="463"/>
        <source>Filter definitions have been updated.</source>
        <translation>濾鏡定義已更新。</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="348"/>
        <source>No download was needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="403"/>
        <source>Plugin was called with a filter path with no matching filter:

Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="411"/>
        <location filename="../src/MainWindow.cpp" line="438"/>
        <source>Error parsing filter parameters definition for filter:

%1

Cannot retrieve default parameters.

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="424"/>
        <source>Plugin was called with a command that cannot be recognized as a filter:

Command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="419"/>
        <source>Plugin was called with a command that cannot be parsed:

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="428"/>
        <source>Plugin was called with a command that does not match the provided path:

Path: %1
Command: %2
Command found for this path : %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="459"/>
        <source>Filters update could not be achieved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="586"/>
        <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
        <translation>這次更新由於以下错誤&lt;br/&gt;未能完成:&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="592"/>
        <source>Update error</source>
        <translation>更新出錯</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="792"/>
        <source>Error</source>
        <translation>出錯</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="888"/>
        <source>Waiting for cancelled jobs...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1261"/>
        <source>Import faves</source>
        <translation>導入最愛列</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1261"/>
        <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
        <translation>你要從以下文件導入最愛列嗎？&lt;br/&gt;%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1264"/>
        <source>Don&apos;t ask again</source>
        <translation>不要再問</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1376"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1376"/>
        <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
        <translation>gmic 命令正在運行。&lt;br&gt;你確定要關閉插件嗎?</translation>
    </message>
</context>
<context>
    <name>GmicQt::MultilineTextParameterWidget</name>
    <message>
        <location filename="../src/FilterParameters/MultilineTextParameterWidget.cpp" line="41"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Return</translation>
    </message>
</context>
<context>
    <name>GmicQt::ProgressInfoWidget</name>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="49"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation>G&apos;MIC-Qt 插件正在處理</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="52"/>
        <source>Abort</source>
        <translation>中斷</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="150"/>
        <source>Updating filters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="205"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="218"/>
        <source>[Processing %1 | %2]</source>
        <translation>[處理中 %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="220"/>
        <source>[Processing %1]</source>
        <translation>[處理中 %1]</translation>
    </message>
</context>
<context>
    <name>GmicQt::ProgressInfoWindow</name>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="49"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation>G&apos;MIC-Qt 插件正在處理</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="141"/>
        <source>%1 seconds</source>
        <translation>%1 秒</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="151"/>
        <source>[Processing %1 | %2]</source>
        <translation>[處理中 %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="153"/>
        <source>[Processing %1]</source>
        <translation>[處理中 %1]</translation>
    </message>
</context>
<context>
    <name>GmicQt::SearchFieldWidget</name>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="79"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="80"/>
        <source>Search in filters list (%1)</source>
        <translation>篩選搜尋(%1)</translation>
    </message>
</context>
<context>
    <name>GmicQt::Updater</name>
    <message>
        <location filename="../src/Updater.cpp" line="196"/>
        <source>Error downloading %1 (empty file?)</source>
        <translation>下載出錯 %1 (空白檔案?)</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="205"/>
        <source>Could not read/decompress %1</source>
        <translation>不能讀取／解壓縮 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="211"/>
        <source>Error creating file %1</source>
        <translation>建立檔案時出錯 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="215"/>
        <source>Error writing file %1</source>
        <translation>寫入檔案出錯 %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="232"/>
        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="265"/>
        <source>Download timeout: %1</source>
        <translation>下載超時：%1</translation>
    </message>
</context>
<context>
    <name>GmicQt::ZoomLevelSelector</name>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="54"/>
        <source>Zoom in</source>
        <translation>放大</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="55"/>
        <source>Zoom out</source>
        <translation>縮小</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="56"/>
        <source>Reset zoom</source>
        <translation>重設縮放比例</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="156"/>
        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
        <translation>警告：預覽可能不準確 (縮放比例已修改)</translation>
    </message>
</context>
<context>
    <name>HeadlessProgressDialog</name>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>對話</translation>
    </message>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="68"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>InOutPanel</name>
    <message>
        <location filename="../ui/inoutpanel.ui" line="40"/>
        <source>Input / Output</source>
        <translation>輸入／輸出</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="92"/>
        <source>Input layers</source>
        <translation>輸入圖層</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="115"/>
        <source>Output mode</source>
        <translation>輸出模式</translation>
    </message>
</context>
<context>
    <name>JpegQualityDialog</name>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="20"/>
        <location filename="../src/Host/None/JpegQualityDialog.cpp" line="12"/>
        <source>JPEG Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="28"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="42"/>
        <source>100</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="60"/>
        <source>Always use this quality for this execution of G&apos;MIC-Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="85"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished">取消 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="92"/>
        <source>&amp;Ok</source>
        <translation type="unfinished">確定 (&amp;O)</translation>
    </message>
</context>
<context>
    <name>LanguageSelectionWidget</name>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="38"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(需要重開)&lt;/I&gt;</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished">MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="18"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="165"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;從遠端下載濾鏡定義&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="168"/>
        <source>Internet</source>
        <translation>互聯網</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="237"/>
        <location filename="../ui/mainwindow.ui" line="244"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="390"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="393"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="484"/>
        <source>Settings...</source>
        <translation>設定...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="500"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="513"/>
        <source>&amp;Cancel</source>
        <translation>取消 (&amp;C)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="526"/>
        <source>&amp;Fullscreen</source>
        <translation>全螢幕 (&amp;F)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="539"/>
        <source>&amp;Apply</source>
        <translation>應用 (&amp;A)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="552"/>
        <source>&amp;OK</source>
        <translation>確定 (&amp;O)</translation>
    </message>
</context>
<context>
    <name>MultilineTextParameterWidget</name>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="29"/>
        <source>Update</source>
        <translation>更新</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWidget</name>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="48"/>
        <source>Abort</source>
        <translation>中斷</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="55"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWindow</name>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="30"/>
        <location filename="../ui/progressinfowindow.ui" line="50"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="91"/>
        <source>Visible</source>
        <translation>可見</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="94"/>
        <source>Available filters (%1)</source>
        <translation>可用的濾鏡(%1)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Select an image to open...</source>
        <translation>開啟圖片...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="80"/>
        <source>Error</source>
        <translation>出錯</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="80"/>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="84"/>
        <source>Default image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Misc.cpp" line="330"/>
        <source>List %1 cannot be merged considering theses runs: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchFieldWidget</name>
    <message>
        <location filename="../ui/SearchFieldWidget.ui" line="20"/>
        <source>Frame</source>
        <translation>Frame</translation>
    </message>
</context>
<context>
    <name>ZoomLevelSelector</name>
    <message>
        <location filename="../ui/zoomlevelselector.ui" line="20"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
</context>
<context>
    <name>gmic_qt_standalone::ImageDialog</name>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="71"/>
        <source>G&apos;MIC-Qt filter output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="82"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="85"/>
        <source>Save as...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="120"/>
        <source>%1 file (*.%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="141"/>
        <source>Save image as...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gmic_qt_standalone::ImageView</name>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
        <source>Error</source>
        <translation type="unfinished">出錯</translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
        <source>Could not write image file %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
